@@ -8,14 +8,19 @@ cfg_unix!(
     pub use unix::MetaDataExt;
 );
 
+use crate::error::Error;
 use std::fs::Metadata;
 use std::ops::{Deref, DerefMut};
 use std::time::SystemTime;
-use crate::error::Error;
 
+/// Empty MetaData
 #[derive(Default, Copy, Clone)]
 pub struct EmptyMetaData;
 
+/// MetaData for [`MemoryMmapFile`]/[`MemoryMmapFileMut`]
+///
+/// [`MemoryMmapFile`]: structs.MemoryMmapFile.html
+/// [`MemoryMmapFileMut`]: structs.MemoryMmapFileMut.html
 #[derive(Copy, Clone)]
 pub struct MemoryMetaData {
     size: u64,
@@ -24,13 +29,14 @@ pub struct MemoryMetaData {
 
 impl MemoryMetaData {
     pub(crate) fn new(size: u64, create_at: SystemTime) -> Self {
-        Self {
-            size,
-            create_at
-        }
+        Self { size, create_at }
     }
 }
 
+/// MetaData for [`DiskMmapFile`]/[`DiskMmapFileMut`]
+///
+/// [`DiskMmapFile`]: structs.DiskMmapFile.html
+/// [`DiskMmapFileMut`]: structs.DiskMmapFileMut.html
 #[derive(Clone)]
 #[repr(transparent)]
 pub struct DiskMetaData {
@@ -57,8 +63,17 @@ impl DerefMut for DiskMetaData {
     }
 }
 
+/// Metadata information about a file.
+/// This structure is returned from the metadata or
+/// symlink_metadata function or method and represents
+/// known metadata about a file such as its permissions, size, modification times, etc
+#[repr(transparent)]
+pub struct MetaData {
+    inner: MetaDataInner,
+}
+
 #[enum_dispatch(MetaDataExt)]
-pub enum MetaData {
+enum MetaDataInner {
     Empty(EmptyMetaData),
     Memory(MemoryMetaData),
     Disk(DiskMetaData),
@@ -66,16 +81,20 @@ pub enum MetaData {
 
 impl MetaData {
     pub(crate) fn empty(meta: EmptyMetaData) -> Self {
-        Self::Empty(meta)
+        Self {
+            inner: MetaDataInner::Empty(meta),
+        }
     }
 
     pub(crate) fn memory(meta: MemoryMetaData) -> Self {
-        Self::Memory(meta)
+        Self {
+            inner: MetaDataInner::Memory(meta),
+        }
     }
 
     pub(crate) fn disk(meta: Metadata) -> Self {
-        Self::Disk(DiskMetaData::new(meta))
+        Self {
+            inner: MetaDataInner::Disk(DiskMetaData::new(meta)),
+        }
     }
 }
-
-
